from Products.validation.interfaces import ivalidator

class NodesValidator:

    __implements__ = (ivalidator,)

    def __init__(self, name):
        self.name = name

# parent, taxon_name, characters, row_position, line_styles, line_direction, line_red, 
# line_green, line_blue, column_position, node_style, end_characters, end_row_position, node_name, red, green, blue
    def __call__(self, value, *args, **kwargs):
        self.lines = {'parent'            : [],
                      'taxon_name'        : [],
                      'characters'        : [],
                      'row_position'     : [],
                      'column_position'  : [],
                      'font_size'         : [],
                      'line_style'        : [],
                      'line_base_style'   : [],
                      'line_stroke_width' : [],
                      'line_direction'    : [],
                      'line_red'          : [],
                      'line_green'        : [],
                      'line_blue'         : [],
                      'node_style'        : [],
                      'node_size'         : [],
                      'node_skew'         : [],
                      'node_red'          : [],
                      'node_green'        : [],
                      'node_blue'         : []}
                  
        # setup and check for item count errors:

        line_errors = []
        line_count = 1
        for node_string in value:
            parent = ""
            taxon_name = ""
            characters = ""
            row_position = ""
            column_position = ""
            font_size = ""
            line_style = ""
            line_base_style = ""
            line_stroke_width = ""
            line_direction = ""
            line_red = ""
            line_green = ""
            line_blue = ""
            node_style = ""
            node_size = ""
            node_skew = ""
            node_red = ""
            node_green = ""
            node_blue = ""
            try:
                items = eval('[%s]' % node_string)
            except:
                return "Mixed numeric and text input somewhere on line %d" % line_count
            if len(items) != 19:
                line_errors.append("%d" % line_count)
            else:
                parent, taxon_name, characters, row_position, column_position, font_size, line_style, line_base_style, line_stroke_width, line_direction, line_red, line_green, line_blue, node_style, node_size, node_skew, node_red, node_green, node_blue = items 
                self.lines['parent'].append(parent)
                self.lines['taxon_name'].append(taxon_name)
                self.lines['characters'].append(characters)
                self.lines['row_position'].append(row_position)
                self.lines['column_position'].append(column_position)
                self.lines['font_size'].append(font_size)
                self.lines['line_style'].append(line_style)
                self.lines['line_base_style'].append(line_base_style)
                self.lines['line_stroke_width'].append(line_stroke_width)
                self.lines['line_direction'].append(line_direction)
                self.lines['line_red'].append(line_red)
                self.lines['line_green'].append(line_green)
                self.lines['line_blue'].append(line_blue)
                self.lines['node_style'].append(node_style)
                self.lines['node_size'].append(node_size)
                self.lines['node_skew'].append(node_skew)
                self.lines['node_red'].append(node_red)
                self.lines['node_green'].append(node_green)
                self.lines['node_blue'].append(node_blue)
            line_count += 1
        if len(line_errors) > 0:
            return "Wrong number of items on lines: %s" % line_errors

        # check for basic conversion errors:

        error_message = ""
        errors = None

        errors = self.checkForParentErrors()
        if errors:
            error_message = "parent (field 1) error on lines: %s" % str(errors)
            return error_message

        errors = self.checkForTaxonNameErrors()
        if errors:
            error_message = "taxon_name (field 2) error on lines: %s" % str(errors)
            return error_message

        errors = self.checkForCharactersErrors()
        if errors:
            error_message = "characters (field 3) error on lines: %s" % str(errors)
            return error_message

        errors = self.checkForRowPositionErrors()
        if errors:
            error_message = "row_position (field 4) error on lines: %s" % str(errors)
            return error_message

        errors = self.checkForLateralPositionErrors()
        if errors:
            error_message = "column_position (field 5) error on lines: %s" % str(errors)
            return error_message

        errors = self.checkForFontSizeErrors()
        if errors:
            error_message = "font_size (field 6) error on lines: %s" % str(errors)
            return error_message

        errors = self.checkForLineStyleErrors()
        if errors:
            error_message = "line_style (field 7) error on lines: %s" % str(errors)
            return error_message

        errors = self.checkForLineBaseStyleErrors()
        if errors:
            error_message = "line_base_style (field 8) error on lines: %s" % str(errors)
            return error_message

        errors = self.checkForLineStrokeWidthErrors()
        if errors:
            error_message = "line_stroke_width (field 9) error on lines: %s" % str(errors)
            return error_message

        errors = self.checkForLineDirectionErrors()
        if errors:
            error_message = "line_direction (field 10) error on lines: %s" % str(errors)
            return error_message

        errors = self.checkForLineRedErrors()
        if errors:
            error_message = "line_red (field 11) error on lines: %s" % str(errors)
            return error_message

        errors = self.checkForLineGreenErrors()
        if errors:
            error_message = "line_green (field 12) error on lines: %s" % str(errors)
            return error_message

        errors = self.checkForLineBlueErrors()
        if errors:
            error_message = "line_blue (field 13) error on lines: %s" % str(errors)
            return error_message

        errors = self.checkForNodeStyleErrors()
        if errors:
            error_message = "node_style (field 14) error on lines: %s" % str(errors)
            return error_message

        errors = self.checkForNodeSizeErrors()
        if errors:
            error_message = "node_size (field 15) error on lines: %s" % str(errors)
            return error_message

        errors = self.checkForNodeSkewErrors()
        if errors:
            error_message = "node_skew (field 16) error on lines: %s" % str(errors)
            return error_message

        errors = self.checkForNodeRedErrors()
        if errors:
            error_message = "node_red (field 17) error on lines: %s" % str(errors)
            return error_message

        errors = self.checkForNodeGreenErrors()
        if errors:
            error_message = "node_green (field 18) error on lines: %s" % str(errors)
            return error_message

        errors = self.checkForNodeBlueErrors()
        if errors:
            error_message = "node_blue (field 19) error on lines: %s" % str(errors)
            return error_message

        # check for start and end time range errors:
        error_message = ""

        # check for color range errors:
        errors = self.checkForColorRangeErrors()
        if errors:
            error_message = "One or more color values out of range (0-255) on lines: %s" % str(errors)
            return error_message

        return 1

    def checkForParentErrors(self):
        return None

    def checkForTaxonNameErrors(self):
        return None

    def checkForCharactersErrors(self):
        line_errors = []
        count = 1
        for characters in self.lines['characters']:
            characters = characters[1:-1]
            if len(characters) > 0:
                characters = characters.split(',')
                for character in characters:
                    try:
                        int(character)
                    except:
                        line_errors.append(count)
                    if len(line_errors) == 0 and int(character) < 0:
                        line_errors.append(count)
            count += 1
        if len(line_errors) > 0:
            return line_errors
        return None

    def checkForRowPositionErrors(self):
        line_errors = []
        count = 1
        for row_position in self.lines['row_position']:
            try:
                float(row_position)
            except:
                line_errors.append(count)
            if len(line_errors) == 0 and float(row_position) <= 0.0:
                line_errors.append(count)
            count += 1
        if len(line_errors) > 0:
            return line_errors
        return None

    def checkForLateralPositionErrors(self):
        line_errors = []
        count = 1
        for column_position in self.lines['column_position']:
            try:
                float(column_position)
            except:
                line_errors.append(count)
            count += 1
        if len(line_errors) > 0:
            return line_errors
        return None

    def checkForFontSizeErrors(self):
        line_errors = []
        count = 1
        for font_size in self.lines['font_size']:
            try:
                int(font_size)
            except:
                line_errors.append(count)
            if len(line_errors) == 0 and int(font_size) <= 0:
                line_errors.append(count)
            count += 1
        if len(line_errors) > 0:
            return line_errors
        return None

    def checkForLineStyleErrors(self):
        line_errors = []
        count = 1
        line_styles = ['solid', 'dashed',]
        for line_style in self.lines['line_style']:
            line_style = line_style.lower()
            if line_style not in line_styles:
                line_errors.append(count)
            count += 1
        if len(line_errors) > 0:
            return line_errors
        return None

    def checkForLineBaseStyleErrors(self):
        line_errors = []
        count = 1
        line_base_styles = ['connected', 'gapped',]
        for line_base_style in self.lines['line_base_style']:
            line_base_style = line_base_style.lower()
            if line_base_style not in line_base_styles:
                line_errors.append(count)
            count += 1
        if len(line_errors) > 0:
            return line_errors
        return None

    def checkForLineStrokeWidthErrors(self):
        line_errors = []
        count = 1
        for line_stroke_width in self.lines['line_stroke_width']:
            try:
                float(line_stroke_width)
            except:
                line_errors.append(count)
            if len(line_errors) == 0 and float(line_stroke_width) <= 0.0:
                line_errors.append(count)
            count += 1
        if len(line_errors) > 0:
            return line_errors
        return None

    def checkForLineDirectionErrors(self):
        line_errors = []
        count = 1
        line_directions = ['root', 'left', 'right', 'up',]
        for line_direction in self.lines['line_direction']:
            line_direction = line_direction.lower()
            if line_direction not in line_directions:
                line_errors.append(count)
            count += 1
        if len(line_errors) > 0:
            return line_errors
        return None

    def checkForNodeStyleErrors(self):
        line_errors = []
        count = 1
        node_styles = ['circle_solid', 'circle_open', 'square_solid', 'square_open',]
        for node_style in self.lines['node_style']:
            node_style = node_style.lower()
            if node_style not in node_styles:
                line_errors.append(count)
            count += 1
        if len(line_errors) > 0:
            return line_errors
        return None

    def checkForNodeSizeErrors(self):
        line_errors = []
        count = 1
        for node_size in self.lines['node_size']:
            try:
                float(node_size)
            except:
                line_errors.append(count)
            if len(line_errors) == 0 and int(node_size) <= 0.0:
                line_errors.append(count)
            count += 1
        if len(line_errors) > 0:
            return line_errors
        return None

    def checkForNodeSkewErrors(self):
        line_errors = []
        count = 1
        for node_skew in self.lines['node_skew']:
            try:
                int(node_skew)
            except:
                line_errors.append(count)
            count += 1
        if len(line_errors) > 0:
            return line_errors
        return None

    def checkForColorErrors(self, color_name):
        line_errors = []
        count = 1
        for color in self.lines[color_name]:
            try:
                int(color)
            except:
                line_errors.append(count)
        if len(line_errors) > 0:
            return line_errors
        return None

    def checkForLineRedErrors(self):
        return self.checkForColorErrors('line_red')

    def checkForLineGreenErrors(self):
        return self.checkForColorErrors('line_green')

    def checkForLineBlueErrors(self):
        return self.checkForColorErrors('line_blue')

    def checkForNodeRedErrors(self):
        return self.checkForColorErrors('node_red')

    def checkForNodeGreenErrors(self):
        return self.checkForColorErrors('node_green')

    def checkForNodeBlueErrors(self):
        return self.checkForColorErrors('node_blue')

    def checkForColorRangeErrors(self):
        line_errors = []
        for i in range(len(self.lines['line_red'])):
            red = int(self.lines['line_red'][i])
            green = int(self.lines['line_green'][i])
            blue = int(self.lines['line_blue'][i])
            red2 = int(self.lines['node_red'][i])
            green2 = int(self.lines['node_green'][i])
            blue2 = int(self.lines['node_blue'][i])

            # must be between 0 and 255
            if red < 0 or red > 255 or green < 0 or green > 255 or blue < 0 or blue > 255:
                line_errors.append(i+1)
            if red2 < 0 or red2 > 255 or green2 < 0 or green2 > 255 or blue2 < 0 or blue2 > 255:
                line_errors.append(i+1)
        if len(line_errors) > 0:
            return line_errors
        return None

