# Amniotes are "land" vertebrate animals -- with the evolution of the
# amniote egg, with it's better-developed shell, vertebrates were free to
# move beyond the "amphibian" lifestyle.  The two main groups within
# Aminiota are Synapsida (which includes Permian-Triassic early forms as
# well as Mammalia) and Reptilia (turtles, lizards, crocs, birds, and all
# of their extinct relatives).  This phylogenetic tree, or cladogram, comes
# from Figure 17.39 in 'Bringing Fossils to Life: An Introduction to
# Paleobiology', second edition, 2004, by Donald Prothero. There are no
# long character descriptions given here, but further work on this can make 
# this program much more useful. For instance, versions of the imagemap can
# include mouseover tooltips for long descriptions. For a more complete
# version of this and other parts of tree of Life, see tolweb.org.

# number, short_description, long_description
sample_amniote_characters = ["1, 'amniote egg', 'amniote egg'",
                             "2, 'keratinized skin', 'keratinized skin'",
                             "3, 'color vision', 'color vision'",
                             "4, 'uric acid', 'uric acid'",
                             "5, 'rapid eye focusing', 'rapid eye focusing'",
                             "6, 'third eyelid', 'third eyelid'",
                             "7, 'specialized ear region', 'specialized ear region'",
                             "8, 'broad fifth metatarsal', 'broad fifth metatarsal'",
                             "9, 'two temporal fenestrae', 'two temporal fenestrae'",
                             "10, 'suborbital fenestra in palate', 'suborbital fenestra in palate'",
                             "11, 'eardrum', 'eardrum'",
                             "12, 'high-frequency hearing', 'high-frequency hearing'",
                             "13, 'enhanced locomotion', 'enhanced locomotion'",
                             "14, 'transverse cloaca', 'transverse cloaca'",
                             "15, 'hemipenes', 'hemipenes'",
                             "16, 'forked tongue', 'forked tongue'",
                             "17, 'gizzard', 'gizzard'",
                             "18, 'upright posture', 'upright posture'",
                             "19, 'advanced hearing', 'advanced hearing'",
                             "20, 'advanced circulatory system', 'advanced circulatory system'",
                             "21, 'perforate acetabulum', 'perforate acetabulum'"]
                             
# parent, taxon_name, characters, row_position, column_position, font_size, line_style, line_base_style, line_stroke_width, branch_direction, line_red, line_green, line_blue, node_style, node_size, node_skew, node_red, node_green, node_blue
sample_amniote_nodes = ["'root',         'xxxx1',                     '[]',            1,  1, 14, 'solid', 'connected', 2.0, 'root',  0, 0, 0, 'circle_solid',  5.0,   0, 0, 0, 0",
                        "'xxxx1',        'anthracosaurs',             '[]',           19,  1, 14, 'solid', 'connected', 2.0, 'left',  0, 0, 0, 'circle_solid',  5.0, -20, 0, 0, 0",
                        "'xxxx1',        'Amniota',                   '[1]',           2,  2, 14, 'solid', 'connected', 2.0, 'right', 0, 0, 0, 'circle_solid',  5.0,   0, 0, 0, 0",
                        "'Amniota',      'Synapsida (mammals +)',     '[]',           19,  2, 14, 'solid', 'connected', 2.0, 'left',  0, 0, 0, 'circle_solid',  5.0, -20, 0, 0, 0",
                        "'Amniota',      'Reptilia',                  '[2,3,4,5,6]',   4,  4, 14, 'solid', 'connected', 2.0, 'right', 0, 0, 0, 'circle_solid',  5.0,   0, 0, 0, 0",
                        "'Reptilia',     'Anapsida',                  '[7,8]',        17,  4, 14, 'solid', 'connected', 2.0, 'left',  0, 0, 0, 'circle_solid',  5.0, -20, 0, 0, 0",
                        "'Anapsida',     'procolophonids',            '[]',           19,  3, 14, 'solid', 'connected', 2.0, 'left',  0, 0, 0, 'circle_solid',  5.0, -20, 0, 0, 0",
                        "'Anapsida',     'parieasaurs',               '[]',           19,  4, 14, 'solid', 'connected', 2.0, 'up',    0, 0, 0, 'circle_solid',  5.0,   0, 0, 0, 0",
                        "'Anapsida',     'turtles',                   '[]',           19,  5, 14, 'solid', 'connected', 2.0, 'right', 0, 0, 0, 'circle_solid',  5.0,   0, 0, 0, 0",
                        "'Reptilia',     'Diapsida',                  '[9,10]',        6,  6, 14, 'solid', 'connected', 2.0, 'right', 0, 0, 0, 'circle_solid',  5.0,   0, 0, 0, 0",
                        "'Diapsida',     'captorhinids',              '[]',           19,  6, 14, 'solid', 'connected', 2.0, 'left',  0, 0, 0, 'circle_solid',  5.0, -20, 0, 0, 0",
                        "'Diapsida',     'xxxx2',                     '[]',            7,  7, 14, 'solid', 'connected', 2.0, 'right', 0, 0, 0, 'circle_solid',  5.0,   0, 0, 0, 0",
                        "'xxxx2',        'Euryapsida',                '[]',           18,  7, 14, 'solid', 'connected', 2.0, 'left',  0, 0, 0, 'circle_solid',  5.0, -20, 0, 0, 0",
                        "'Euryapsida',   'ichthyosaurs',              '[]',           19,  7, 14, 'solid', 'connected', 2.0, 'left',  0, 0, 0, 'circle_solid',  5.0, -20, 0, 0, 0",
                        "'Euryapsida',   'plesiosaurs',               '[]',           19,  8, 14, 'solid', 'connected', 2.0, 'right', 0, 0, 0, 'circle_solid',  5.0,   0, 0, 0, 0",
                        "'xxxx2',        'Sauria',                    '[11,12,13]',    9,  9, 14, 'solid', 'connected', 2.0, 'right', 0, 0, 0, 'circle_solid',  5.0,   0, 0, 0, 0",
                        "'Sauria',       'Lepidosauria',              '[14,15,16]',   15,  9, 14, 'solid', 'connected', 2.0, 'left',  0, 0, 0, 'circle_solid',  5.0, -20, 0, 0, 0",
                        "'Lepidosauria', 'tuatara',                   '[]',           19,  9, 14, 'solid', 'connected', 2.0, 'left',  0, 0, 0, 'circle_solid',  5.0, -20, 0, 0, 0",
                        "'Lepidosauria', 'xxxx3',                     '[]',           16, 10, 14, 'solid', 'connected', 2.0, 'right', 0, 0, 0, 'circle_solid',  5.0,   0, 0, 0, 0",
                        "'xxxx3',        'most lizards',              '[]',           19, 10, 14, 'solid', 'connected', 2.0, 'left',  0, 0, 0, 'circle_solid',  5.0, -20, 0, 0, 0",
                        "'xxxx3',        'xxxx4',                     '[]',           17, 11, 14, 'solid', 'connected', 2.0, 'right', 0, 0, 0, 'circle_solid',  5.0,   0, 0, 0, 0",
                        "'xxxx4',        'monitor lizards',           '[]',           19, 11, 14, 'solid', 'connected', 2.0, 'left',  0, 0, 0, 'circle_solid',  5.0, -20, 0, 0, 0",
                        "'xxxx4',        'xxxx5',                     '[]',           18, 12, 14, 'solid', 'connected', 2.0, 'right', 0, 0, 0, 'circle_solid',  5.0,   0, 0, 0, 0",
                        "'xxxx5',        'mosasaurs',                 '[]',           19, 12, 14, 'solid', 'connected', 2.0, 'left',  0, 0, 0, 'circle_solid',  5.0, -20, 0, 0, 0",
                        "'xxxx5',        'snakes',                    '[]',           19, 13, 14, 'solid', 'connected', 2.0, 'right', 0, 0, 0, 'circle_solid',  5.0,   0, 0, 0, 0",
                        "'Sauria',       'Archosauria',               '[17,18,19,20]',14, 14, 14, 'solid', 'connected', 2.0, 'right', 0, 0, 0, 'circle_solid',  5.0,   0, 0, 0, 0",
                        "'Archosauria',  'crocodilians',              '[]',           19, 14, 14, 'solid', 'connected', 2.0, 'left',  0, 0, 0, 'circle_solid',  5.0, -20, 0, 0, 0",
                        "'Archosauria',  'Ornithodira',               '[]',           15, 15, 14, 'solid', 'connected', 2.0, 'right', 0, 0, 0, 'circle_solid',  5.0,   0, 0, 0, 0",
                        "'Ornithodira',  'pterosaurs',                '[]',           19, 15, 14, 'solid', 'connected', 2.0, 'left',  0, 0, 0, 'circle_solid',  5.0, -20, 0, 0, 0",
                        "'Ornithodira',  'Dinosauria',                '[21]',         16, 16, 14, 'solid', 'connected', 2.0, 'right', 0, 0, 0, 'circle_solid',  5.0,   0, 0, 0, 0",
                        "'Dinosauria',   'Ornithischia',              '[]',           19, 16, 14, 'solid', 'connected', 2.0, 'left',  0, 0, 0, 'circle_solid',  5.0, -20, 0, 0, 0",
                        "'Dinosauria',   'Saurischia',                '[]',           17, 17, 14, 'solid', 'connected', 2.0, 'right', 0, 0, 0, 'circle_solid',  5.0,   0, 0, 0, 0",
                        "'Saurischia',   'Sauropodamorpha',           '[]',           19, 17, 14, 'solid', 'connected', 2.0, 'left',  0, 0, 0, 'circle_solid',  5.0, -20, 0, 0, 0",
                        "'Saurischia',   'Tetanurae',                 '[]',           18, 18, 14, 'solid', 'connected', 2.0, 'right', 0, 0, 0, 'circle_solid',  5.0,   0, 0, 0, 0",
                        "'Tetanurae',    'theropods',                 '[]',           19, 18, 14, 'solid', 'connected', 2.0, 'left',  0, 0, 0, 'circle_solid',  5.0, -20, 0, 0, 0",
                        "'Tetanurae',    'Aves',                      '[]',           19, 19, 14, 'solid', 'connected', 2.0, 'right', 0, 0, 0, 'circle_solid',  5.0,   0, 0, 0, 0"]

